@@ -1,10 +1,10 @@
-# Copyright 2019 Q-CTRL Pty Ltd & Q-CTRL Inc
+# Copyright 2022 Q-CTRL
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
+#    http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,8 +18,8 @@ qctrlpyquil
 ===========
 """
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 
 from .program import convert_dds_to_pyquil_program
 
-__all__ = ['convert_dds_to_pyquil_program']
+__all__ = ["convert_dds_to_pyquil_program"]
